/* gtkmm example Copyright (C) 2002 gtkmm development team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "examplewindow.h"
#include <iostream>

ExampleWindow::ExampleWindow()
: m_button("Select file", Gtk::FileChooser::Action::OPEN)
{
  set_default_size(200, -1);

  set_title("FileChooserButton example");

  m_button.set_margin(10);
  add(m_button);

  //Allow our file chooser to select remote URIs,
  //for instance via bookmarked servers:
  m_button.set_local_only(false);
}

ExampleWindow::~ExampleWindow()
{
}

